@@ -17,17 +17,18 @@ class LRPCVInterpreter(Interpreter):
     def __init__(self,
                  paddle_model,
                  use_cuda=True,
+                 device='gpu:0',
                  model_input_shape=[3, 224, 224]) -> None:
         """
-        Initialize the LRPCVInterpreter.
 
         Args:
-            paddle_model (callable): A paddle model that outputs predictions.
-            use_cuda (bool, optional): Whether or not to use cuda. Default: True
+            paddle_model (callable): A model with ``forward`` and possibly ``backward`` functions.
+            device (str): The device used for running `paddle_model`, options: ``cpu``, ``gpu:0``, ``gpu:1`` etc.
+            use_cuda (bool):  Would be deprecated soon. Use ``device`` directly.
             model_input_shape (list, optional): The input shape of the model. Default: [3, 224, 224]
 
         """
-        Interpreter.__init__(self, paddle_model, 'gpu:0', use_cuda)
+        Interpreter.__init__(self, paddle_model, device, use_cuda)
         self.model_input_shape = model_input_shape
         self.paddle_prepared = False
 
@@ -44,9 +45,10 @@ class LRPCVInterpreter(Interpreter):
             labels (list or tuple or numpy.ndarray, optional): The target labels to analyze. The number of labels should be equal to the number of images. If None, the most likely label for each image will be used. Default: None
             visual (bool, optional): Whether or not to visualize the processed image. Default: True
             save_path (str or list of strs or None, optional): The filepath(s) to save the processed image(s). If None, the image will not be saved. Default: None
-
-        :return: interpretations/Relevance map for each image
-        :rtype: numpy.ndarray
+        
+        Returns:
+            [numpy.ndarray]: interpretations/Relevance map for images.
+            
         """
         imgs, data = preprocess_inputs(inputs, self.model_input_shape)
         
